/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell.command;

import static org.junit.Assert.assertNotNull;

import java.net.URL;

import org.junit.Before;
import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.PetalsAdministrationFactory;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.DuplicatedServiceException;
import org.ow2.petals.admin.api.exception.MissingServiceException;
import org.ow2.petals.cli.AbstractCliTest;

/**
 * Abstract class with useful method for artifact command test.
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class AbstractArtifactCommandTest extends AbstractCliTest {

    protected final static String COMPONENT_FILENAME = "jbi-component-soap.zip";

    protected final static URL COMPONENT_URL = Thread.currentThread().getContextClassLoader()
            .getResource(COMPONENT_FILENAME);

    protected final static String COMPONENT_ID = "petals-bc-soap-provide";

    protected final static String SA_PERMISSION_FILENAME = "sa-permission.zip";

    protected final static URL SA_URL = Thread.currentThread().getContextClassLoader()
            .getResource(SA_PERMISSION_FILENAME);

    protected final static String SA_SOAPID_FILENAME = "sa-soapid.zip";

    protected final static URL SA_SOAP_ID_URL = Thread.currentThread().getContextClassLoader()
            .getResource(SA_SOAPID_FILENAME);

    protected final static String SL_FILENAME = "petals-sl-mysql-5.1.5.zip";

    protected final static String SL_VERSION = "5.1.5";

    protected final URL slURL = Thread.currentThread().getContextClassLoader().getResource(SL_FILENAME);

    protected final static String SL2_FILENAME = "petals-sl-mysql-4.1.5.zip";

    protected final static String SL2_VERSION = "4.1.5";

    protected final URL sl2URL = Thread.currentThread().getContextClassLoader().getResource(SL2_FILENAME);

    protected DummyShellWrapper dummyShellWrapper;

    @Before
    public void beforeTest() {
        assertNotNull("Component archive '" + COMPONENT_FILENAME + "' not found !", COMPONENT_URL);
        assertNotNull("SA archive '" + SA_PERMISSION_FILENAME + "' not found !", SA_URL);
        assertNotNull("SA archive '" + SA_SOAPID_FILENAME + "' not found !", SA_SOAP_ID_URL);
        assertNotNull("SL archive '" + SL_FILENAME + "' not found !", this.slURL);
        assertNotNull("SL archive '" + SL2_FILENAME + "' not found !", this.sl2URL);
    }

    @Before
    public void createAndConnectDummyShellWrapper() {
        this.dummyShellWrapper = new DummyShellWrapper();
        this.dummyShellWrapper.getShell().onConnectionEstablished();
    }


    /**
     * Deploy specified artifacts.
     * 
     * @param urls
     * @throws ArtifactAdministrationException
     * @throws MissingServiceException
     * @throws DuplicatedServiceException
     */
    protected void deployStartArtifact(URL... urls) throws ArtifactAdministrationException {
        try {
            final ArtifactAdministration artifactAdministration = PetalsAdministrationFactory.getInstance()
                    .newPetalsAdministrationAPI().newArtifactAdministration();
            for (final URL url : urls) {
                artifactAdministration.deployAndStartArtifact(url, false);
            }
        } catch (final DuplicatedServiceException e) {
            throw new ArtifactAdministrationException(e);
        } catch (final MissingServiceException e) {
            throw new ArtifactAdministrationException(e);
        }
    }
}
